.. _api-reference:

#############
API Reference
#############

This document is a reference for the major modules, objects, and functions that constitute ``alchemiscale``.
See :ref:`library-layout` for a higher-level overview of these modules.

.. toctree::
   :maxdepth: 1

   ./api/models
   ./api/settings
   ./api/cli
   ./api/storage
   ./api/base
   ./api/interface
   ./api/compute
   ./api/security
   ./api/strategist
